@@ -1,22 +1,23 @@
 
 #' @title Propensity score weighting
 #' @description \code{psw} is the main function to perfrom propensity score weighting analysis for (1) visualization of the propensity score distribution in both treatment groups,
-#' (2) covariate balance diagnosis, (3) propensity score model specification test, (4) treatment effect estimation and inference, and (5) doubly robust estimation when applicable.
+#' (2) covariate balance diagnosis, (3) propensity score model specification test, (4) treatment effect estimation and inference, and (5) augmented estimation with outcome regression
+#' when applicable.
 #' @param data data frame to be used.
 #' @param form.ps propensity score model.
 #' @param weight weighting method to be used. Available methods are \code{"ATE"},  \code{"ATT"}, \code{"ATC"}, \code{"MW"}, \code{"OVERLAP"}, and \code{"TRAPEZOIDAL"}.
 #' @param std.diff calculate standardized mean difference as a percentage, \code{std.diff=FALSE} by default.
+#' @param V.name a vector of covariates on which standardized mean difference is computed or the specification test is performed. If \code{V.name = NULL}, the covariates in propensity score model are used.
 #' @param mirror.hist mirror histogram showing the propensity score distributions in both treatment groups, \code{mirror.hist=FALSE} by default.
-#' @param add.weight add propensity score weights to the mirror histogram, \code{add.weight=FALSE} by default and it is not available for \code{weight="ATE", "ATT"} or \code{"ATC"}.
+#' @param add.weight add propensity score weights to the mirror histogram, \code{add.weight=FALSE} by default and it is not available for \code{weight="ATE"},  \code{"ATT"}, or \code{"ATC"}.
 #' @param nclass number of breaks in the mirror histogram.
 #' @param wt estimate the weighted estimator, \code{wt=FALSE} by default.
 #' @param out.var outcome variable, needed when \code{wt=TRUE}.
 #' @param family outcome family, either \code{"gaussian"} or \code{"binomial"}, \code{family="gaussian"} by default.
-#' @param dr estimate the doubly robust estimator, \code{dr=FALSE} by default.
-#' @param form.outcome outcome model, needed when \code{dr=TRUE}.
+#' @param aug estimate the augmented estimator, \code{aug=FALSE} by default.
+#' @param form.outcome outcome model, needed when \code{aug=TRUE}.
 #' @param spec.test propensity score model specification test, \code{spec.test=FALSE} by default.
 #' Note that specification test is not available for \code{weight="OVERLAP"}.
-#' @param V.name a vector of covariates on which the specification test is performed, needed when \code{spec.test=TRUE}.
 #' @param trans.type a vector of the same length as \code{V.name} that specifies the transformation type for each element in \code{V.name}.
 #' Available transformations are \code{"identity"}, \code{"log"}, \code{"logit"}, \code{"sqrt"}, \code{"Fisher"}.
 #' Needed when \code{spec.test=T}, and no transformation is perfomred with \code{"identity"}. See Details.
@@ -42,8 +43,9 @@
 #'
 #' A mirror histogram is produced to visualize the propensity score distributions in both treatment groups. In the mirror histogram, above the horizontal line
 #' is the histogram of the propensiy scores of the control group, below is that of the treated group. The vertical axis of the histogram is the frequency. When
-#' \code{mirror.hist.weight=TRUE}, the height of the shaded bar is the summation of the weights of subjects within the corresponding propensity score stratum.
-#' For weighting methods of \code{"ATE"}, \code{"ATT"}, \code{"ATC"}, \code{add.weight} is not recommended for visual display because weights may be larger than 1.
+#' \code{add.weight=TRUE}, the height of the green bar added to mirror histogram is the summation of the weights of subjects within the corresponding propensity
+#' score stratum. For weighting methods of \code{"ATE"}, \code{"ATT"}, \code{"ATC"}, \code{add.weight} is not recommended for visualization because weights may
+#' be larger than 1.
 #'
 #' Standardized mean difference for a covariate is defiend as
 #'  \deqn{ \frac{100 (\bar{x}_1 - \bar{x}_0)}{\sqrt{\frac{s_1^2 + s_0^2}{2} } },}
@@ -57,17 +59,22 @@
 #' where \eqn{\boldsymbol{V}_i} is a vector of covariates whose balance are examined, and \eqn{\boldsymbol{g}(.)} is a vector of monotone smooth transformations for the input.
 #' Transformation type is specified by argument \code{trans.type}, and available transformation types are \code{"identity"}, \code{"log"}, \code{"logit"}, \code{"sqrt"}, \code{"Fisher"}.
 #' These transformations are recommended to improve the finite sample performance of the specification test. Log transformation (\code{"log"}) and square root transformation (\code{"sqrt"})
-#' are recommended for skewed data, Logit transformation (\code{"logit"}) for binary data, and Fisher z-transformation (\code{"Fisher"}) for bounded data between \eqn{(-1, 1)}.
+#' are recommended for skewed data, logit transformation (\code{"logit"}) for binary data, and Fisher z-transformation (\code{"Fisher"}) for bounded data between \eqn{(-1, 1)}.
 #' The current version of model specification test is not available for \code{weight="OVERLAP"} because it results in zero standardized difference.
 #'
 #' For estimation of mean difference (\code{"gaussian"} family) or risk difference (\code{"binomial"} family), the weighted estimator is
 #' \deqn{ \hat{\Delta} = \frac{\sum_{i=1}^n W_i Z_i Y_i}{\sum_{i=1}^n W_i Z_i} - \frac{\sum_{i=1}^n W_i (1-Z_i) Y_i}{\sum_{i=1}^n W_i (1-Z_i)}, }
-#' and the doubly robust estimator is
-#'\deqn{\hat{\Delta}_{DR} = \frac{ \sum_{i=1}^n \omega(e_i) \{ m_{1i} - m_{0i} \}}{ \sum_{i=1}^n \omega(e_i) } + \frac{ \sum_{i=1}^n W_i Z_i \{ Y_i - m_{1i} \}}{ \sum_{i=1}^n W_i Z_i } - \frac{ \sum_{i=1}^n W_i (1-Z_i) \{ Y_i - m_{0i} \}}{ \sum_{i=1}^n W_i (1-Z_i)},}
-#'where \eqn{m_{1i} = E[Y_i | \boldsymbol{X_i}, Z_i=1]} is the conditional expectation of outcome when treated given covariates \eqn{\boldsymbol{X}_i},
-#'and \eqn{m_{0i} = E[Y_i | \boldsymbol{X_i}, Z_i=0]} is the conditional expectation of outcome when control given covariates \eqn{\boldsymbol{X}_i}.
-#'When the outcome belongs to the \code{"binomial"} family, the marginal probability is used to estimate risk ratio, odds ratio and log odds ratio.
-#'Sandwich variance estimation is used to adjust for the uncertainty in the estimated propensity score (Li and Greene, 2013).
+#' and the augmented estimator is
+#' \deqn{\hat{\Delta}_{aug} = \frac{ \sum_{i=1}^n \omega(e_i) \{ m_{1i} - m_{0i} \}}{ \sum_{i=1}^n \omega(e_i) } + \frac{ \sum_{i=1}^n W_i Z_i \{ Y_i - m_{1i} \}}{ \sum_{i=1}^n W_i Z_i } - \frac{ \sum_{i=1}^n W_i (1-Z_i) \{ Y_i - m_{0i} \}}{ \sum_{i=1}^n W_i (1-Z_i)},}
+#' where \eqn{m_{1i} = E[Y_i | \boldsymbol{X_i}, Z_i=1]} is the conditional expectation of outcome when treated given covariates \eqn{\boldsymbol{X}_i},
+#' and \eqn{m_{0i} = E[Y_i | \boldsymbol{X_i}, Z_i=0]} is the conditional expectation of outcome when control given covariates \eqn{\boldsymbol{X}_i}.
+#' When the outcome belongs to the \code{"binomial"} family, the marginal probability is used to estimate risk ratio, odds ratio and log odds ratio.
+#' Sandwich variance estimation is used to adjust for the sampling variability in the estimated propensity scores (Li and Greene, 2013).
+#'
+#' The augmented estimator \eqn{ \hat{\Delta}_{aug} } incorporates regression models for the outcome variable and has simliar properties as the doubly robust IPW estimator
+#' (Lunceford and Davidian, 2004), but with one difference. The estimand of IPW estimator does not depend on the propensity score because \eqn{\omega(e_i) = 1},
+#' while the estimands of other weighting methods depend on propensity score specification. Nonetheless, the proposed augmented estimator converges to the estimand
+#' defined by the corresponding propensity score model.
 #'
 #' @return \code{psw} returns a list of elements depending on the supplied arguments.
 #' \item{weight}{weighting method.}
@@ -79,23 +86,19 @@
 #' \item{std.diff.after}{A data frame of weighed mean, variance, and standardized mean difference for covariates in \code{V.name} by treatment groups after weighting.}
 #' \item{est.wt}{weighted estimator for mean difference when \code{wt=T} and \code{family = "gaussian"}.}
 #' \item{std.wt}{standard error for \code{est.wt}.}
-#' \item{est.dr}{doubly robust estimator for mean difference when \code{dr=T} and \code{family = "gaussian"}.}
-#' \item{std.dr}{standard error for \code{est.dr}.}
+#' \item{est.aug}{augmented estimator for mean difference when \code{aug=T} and \code{family = "gaussian"}.}
+#' \item{std.aug}{standard error for \code{est.aug}.}
 #' \item{est.risk.wt}{weighted estimator for risk difference when \code{wt=T} and \code{family = "binomial"}.}
 #' \item{std.risk.wt}{standard error for \code{est.risk.wt}.}
-#' \item{est.risk.dr}{doubly robust estimator for risk difference when \code{dr=T} and \code{family = "binomial"}.}
-#' \item{std.risk.dr}{standard error for \code{est.risk.dr}.}
+#' \item{est.risk.aug}{augmented estimator for risk difference when \code{aug=T} and \code{family = "binomial"}.}
+#' \item{std.risk.aug}{standard error for \code{est.risk.aug}.}
 #' \item{est.rr.wt}{weighted estimator for relative risk when \code{wt=T} and \code{family = "binomial"}.}
 #' \item{std.rr.wt}{standard error for \code{est.rr.wt}.}
 #' \item{est.or.wt}{weighted estimator for odds ratio when \code{wt=T} and \code{family = "binomial"}.}
 #' \item{std.or.wt}{standard error for \code{est.or.wt}.}
 #' \item{est.lor.wt}{weighted estimator for log odds ratio when \code{wt=T} and \code{family = "binomial"}.}
 #' \item{std.lor.wt}{standard error for \code{est.lor.wt}.}
-#' \item{V.name}{covariates in the specification test or balance diagnosis.}
-#' \item{g.B1.hat}{a vector of transformed weighted average for covariates in the treated group when \code{spec.test=T}.}
-#' \item{g.B0.hat}{a vector of transformed weighted average for covariates in the control group when \code{spec.test=T}.}
-#' \item{B.hat}{difference between \code{eta.B1.hat} and \code{eta.B0.hat} when \code{spec.test=T}.}
-#' \item{var.B.hat}{covariance matrix for \code{B.hat} when \code{spec.test=T}.}
+#' \item{V.name}{covariates for balance diagnosis and specification test.}
 #' \item{test.stat}{test statistic for the specification test, which follows the \eqn{\chi^2_{df}} distribution under the null, available when \code{spec.test=T}.}
 #' \item{df}{degree of freedom for the specification test, \code{df=rank(var.B.hat)}, available when \code{spec.test=T}.}
 #' \item{pvalue}{pvalue of the specification test when \code{spec.test=T}.}
@@ -107,26 +110,28 @@
 #' # Propensity score model
 #' form.ps <- "Z ~ X1 + X2 + X3 + X4";
 #'
-#' #1. Standardized differnce with "ATE"
-#' tmp1 <- psw( data = test_data, form.ps = form.ps, weight = "ATE" );
+#' # A vector of covariates
+#' V.name <- c( "X1", "X2", "X3", "X4" );
 #'
-#' #2. Mirror histogram and add weights to it with "MW".
+#' #1. Standardized differnce with "ATE"
+#' tmp1 <- psw( data = test_data, form.ps = form.ps, weight = "ATE",
+#' std.diff = TRUE,  V.name = V.name );
+#'
+#' #2. Mirror histogram and add estimated matching weight to it
 #' tmp2 <- psw( data = test_data, form.ps = form.ps, weight = "MW",
-#' add.weight = T );
+#' mirror.hist = TRUE, add.weight = TRUE );
 #'
 #' #3. Estimate average treatment effect with "ATE"
 #' tmp3 <- psw( data = test_data, form.ps = form.ps, weight = "ATE", wt = TRUE,
 #' out.var = "Y", family = "gaussian" );
 #'
-#' #4. Doubly robust estimator with "OVERLAP"
+#' #4. Augmented estimator with "OVERLAP"
 #' # outcome model
 #' form.out <- "Y ~ X1 + X2 + X3 + X4";
-#' tmp4 <- psw( data = test_data, form.ps = form.ps, weight = "OVERLAP", dr = TRUE,
+#' tmp4 <- psw( data = test_data, form.ps = form.ps, weight = "OVERLAP", aug = TRUE,
 #' form.outcome = form.out, family = "gaussian" );
 #'
 #' #5. Propensity score model specification test with "MW".
-#' # A vector of covariates
-#' V.name <- c( "X1", "X2", "X3", "X4" );
 #' # A vector of transformation types for covariates in V.name.
 #' trans.type <- c( "identity", "identity", "logit", "logit" );
 #' tmp5 <- psw( data = test_data, form.ps = form.ps, weight = "MW", spec.test = TRUE,
@@ -135,14 +140,16 @@
 #' @references Hirano K, Imbens GW and Ridder G. "Efficient estimation of average treatment effects using the estimated propensity score." Econometrica 2003; 71(4): 1161-1189.
 #' @references Li F, Morgan KL and Zaslavsky AM. "Balancing covariates via propensity score weighting." J Am Stat Assoc 2016; DOI:10.1080/01621459.2016.1260466.
 #' @references Li L and Greene T. "A weighting analogue to pair matching in propensity score analysis." Int J Biostat 2013; 9(2):215-234.
+#' @references Lunceford JK and Davidian M. Stratification and weighting via the propensity score in estimation of causal treatment effects: a comparative study. Stat Med. 2004; 23(19):2937-2960.
 #'
-#' @seealso \link{psw.balance}, \link{psw.spec.test}, \link{psw.wt}, \link{psw.dr}, \link{psw.mirror.hist}.
+#' @seealso \link{psw.balance}, \link{psw.spec.test}, \link{psw.wt}, \link{psw.aug}, \link{psw.mirror.hist}.
 #' @import stats
 #' @export
-psw <- function( data, form.ps, weight, std.diff = FALSE, mirror.hist = FALSE, add.weight = FALSE, nclass = 50,
+psw <- function( data, form.ps, weight, std.diff = FALSE, V.name = NULL,
+                 mirror.hist = FALSE, add.weight = FALSE, nclass = 50,
                  wt = FALSE, out.var = NULL, family = "gaussian",
-                 dr = FALSE, form.outcome = NULL,
-                 spec.test = F, V.name = NULL, trans.type = NULL,
+                 aug = FALSE, form.outcome = NULL,
+                 spec.test = F, trans.type = NULL,
                  K = 4 ) {
   # Main function to peform propoensity weighting analysis
   #
@@ -156,15 +163,12 @@ psw <- function( data, form.ps, weight, std.diff = FALSE, mirror.hist = FALSE, a
   #   nclass: number of breaks in mirror histogram
   #   std.diff: calculate standardized mean difference? TRUE by default
   #   wt: estimate weighted estimator? TRUE by defaulst
-  #   dr: estimate doubly robust estimator? FALSE by default
+  #   aug: estimate augmented estimator? FALSE by default
   #   spec.test: peform propensity score model specification test? spec.test = F by default
-  #   V.name: names of covariates that are used for propensity score model specification test
+  #   V.name: names of covariates that are used for balance diagnosis and propensity score model specification test
   #   trans.type: tranformation type for propensity score model specification test
   #   K: coefficient of trapezoidal weight, K is the slope of trapezoidal edge, K = 4 by default
   #
-  # Return
-  #   A list composed of point estimation (est), standard error (std), supplied proprnsity model, propensity score coefficients,
-  #   fitted propensity score, propensity score weights.
 
   # Outcome family can only be "gaussian" or "binomial"
   if ( !( family %in% c( "gaussian", "binomial" ) ) ) {
@@ -184,6 +188,11 @@ psw <- function( data, form.ps, weight, std.diff = FALSE, mirror.hist = FALSE, a
   ps.hat <- out.ps$ps.hat;  # estimated ps
   beta.hat <- as.numeric(coef(out.ps$fm));
 
+  # covariates for balance checking and specification test
+  if ( is.null( V.name ) ) {
+    V.name <- Xname;
+  }
+
   omega <- sapply( ps.hat, calc.omega, weight = weight, delta = 0.002, K = K);
   Q <- data[ , trt.var ] * ps.hat + ( 1 - data[ , trt.var ] ) * ( 1 - ps.hat );  # denominator of generic weight;
   W <- omega/Q;  # generic weight;
@@ -204,9 +213,6 @@ psw <- function( data, form.ps, weight, std.diff = FALSE, mirror.hist = FALSE, a
 
   ## standardized mean difference and plot
   if ( std.diff ) {
-
-    #res.balance <- psw.balance.core( Xmat = as.matrix( data[ , Xname, drop=F ] ), Xname = Xname,
-    #                                 weight = weight, W = W, Z = as.numeric( data[ , trt.var ] ) );
     res.balance <- psw.balance.core( Xmat = as.matrix( data[ , V.name, drop=F ] ), Xname = V.name,
                                      weight = weight, W = W, Z = as.numeric( data[ , trt.var ] ) );
     res$std.diff.before <- res.balance$std.diff.before;
@@ -255,33 +261,21 @@ psw <- function( data, form.ps, weight, std.diff = FALSE, mirror.hist = FALSE, a
     }
   }
 
-  ## doubly robust estimator
-  if ( dr ) {
+  ## augmented estimator
+  if ( aug ) {
     # fit outcome model
     out.outcome <- outcome.model( dat = data, form = as.formula(form.outcome), trt.var = trt.var, family=family );
     out.var <- as.character( terms( out.outcome$fm1 )[[2]] );
-    res.dr <- psw.dr.core( dat = data, beta.hat = beta.hat, omega = omega, Q = Q, out.ps = out.ps, out.outcome = out.outcome,
+    res.aug <- psw.aug.core( dat = data, beta.hat = beta.hat, omega = omega, Q = Q, out.ps = out.ps, out.outcome = out.outcome,
                            trt.var = trt.var, out.var = out.var, weight = weight, family = family, delta = 0.002, K = K );
     if ( family == "gaussian" ) {
-      res$est.dr <- res.dr$est;
-      res$std.dr <- res.dr$std;
+      res$est.aug <- res.aug$est;
+      res$std.aug <- res.aug$std;
     }
     if ( family == "binomial" ) {
       # risk difference
-      res$est.risk.dr <- res.dr$est.risk;
-      res$std.risk.dr <- res.dr$std.risk;
-
-      # risk ratio
-      res$est.rr.dr <- res.dr$est.rr;
-      res$std.rr.dr <- res.dr$std.rr;
-
-      # odds ratio
-      res$est.or.dr <- res.dr$est.or;
-      res$std.or.dr <- res.dr$std.or;
-
-      # log odds ratio
-      res$est.lor.dr <- res.dr$est.lor;
-      res$std.lor.dr <- res.dr$std.lor;
+      res$est.risk.aug <- res.aug$est.risk;
+      res$std.risk.aug <- res.aug$std.risk;
     }
   }
 
@@ -298,10 +292,6 @@ psw <- function( data, form.ps, weight, std.diff = FALSE, mirror.hist = FALSE, a
     res.spec.test <- psw.spec.test.core( X.mat = X.mat, V.mat = V.mat, V.name =V.name, trt = data[ , trt.var ], beta.hat = beta.hat,
                                          omega = omega,Q = Q, trans.type = trans.type, weight = weight, delta = 0.002, K = K );
     res$V.name <- res.spec.test$V.name;
-    res$g.B1.hat <- res.spec.test$g.B1.hat;
-    res$g.B0.hat <- res.spec.test$g.B0.hat;
-    res$B.hat <- res.spec.test$B.hat;
-    res$var.B.hat <- res.spec.test$var.B.hat;
     res$test.stat <- res.spec.test$test.stat;
     res$df <- res.spec.test$df;
     res$pvalue <- res.spec.test$pvalue;
